@@ -1,8 +1,8 @@
 import six
+import logging
 
 from descarteslabs.common.graft import client
 
-from ... import env
 from ...cereal import serializable
 from ..array import MaskedArray
 from ..containers import CollectionMixin, Dict, KnownDict, List, Slice, Struct, Tuple
@@ -156,9 +156,8 @@ class ImageCollection(BandsMixin, CollectionMixin, ImageCollectionBase):
         If given a list of some non-empty and some empty images, the empties will be dropped.
         """
 
-        self.graft = client.apply_graft(
-            "wf.ImageCollection.from_images", images, env.geoctx
-        )
+        self.graft = client.apply_graft("wf.ImageCollection.from_images", images)
+        self.params = images.params
 
     @classmethod
     @typecheck_promote(
@@ -248,29 +247,23 @@ class ImageCollection(BandsMixin, CollectionMixin, ImageCollectionBase):
             "q1",
             "q3",
         ]:
-            raise ValueError(
-                "Unknown resampler type: {}".format(resampler.literal_value)
-            )
+            raise ValueError(f"Unknown resampler type: {resampler.literal_value!r}")
         if (
             processing_level.literal_value is not None
             and processing_level.literal_value not in ("toa", "surface")
         ):
             raise ValueError(
-                "Unknown processing level: {!r}. Must be None, 'toa', or 'surface'.".format(
-                    processing_level.literal_value
-                )
+                f"Unknown processing level: {processing_level.literal_value!r}. "
+                f"Must be None, 'toa', or 'surface'."
             )
         return cls._from_apply(
             "wf.ImageCollection.from_id",
             product_id,
-            geocontext=env.geoctx,
-            token=env._token,
             start_datetime=start_datetime,
             end_datetime=end_datetime,
             limit=limit,
             resampler=resampler,
             processing_level=processing_level,
-            ruster=env._ruster,
         )
 
     @property
@@ -368,6 +361,11 @@ class ImageCollection(BandsMixin, CollectionMixin, ImageCollectionBase):
         is True, any missing names are dropped, and if none of the names exist,
         returns an empty `ImageCollection`.
 
+        Parameters
+        ----------
+        bands: Str or List[Str]
+            A space-separated string or list of band names
+
         Example
         -------
         >>> from descarteslabs.workflows import ImageCollection
@@ -395,15 +393,19 @@ class ImageCollection(BandsMixin, CollectionMixin, ImageCollectionBase):
         New `ImageCollection`, with bands renamed by position or name.
 
         New names can be given positionally (like ``rename_bands('new_red', 'new_green')``),
-        which renames the i-th band to the i-th argument.
-
-        Or, new names can be given by keywords (like ``rename_bands(red="new_red")``)
-        mapping from old band names to new ones.
-
-        To eliminate ambiguity, names cannot be given both ways.
+        which renames the i-th band to the i-th argument or new names can be given by keywords
+        (like ``rename_bands(red="new_red")``) mapping from old band names to new ones. To eliminate
+        ambiguity, names cannot be given both ways.
 
         If the `ImageCollection` is empty, returns the empty `ImageCollection`.
 
+        Parameters
+        ----------
+        *new_positional_names: Str
+            Positional bands to rename
+        **new_names: Str
+            Keyword bands to rename
+
         Example
         -------
         >>> from descarteslabs.workflows import ImageCollection
@@ -456,16 +458,15 @@ class ImageCollection(BandsMixin, CollectionMixin, ImageCollectionBase):
         >>> type(mean_col).__name__
         'ImageCollection'
         """
-        delayed_func = Function._delay(func, None, self._element_type)
+        func = Function.from_callable(func, self._element_type)
+        result_type = func.return_type
 
-        result_type = type(delayed_func)
-
-        container_type, func = (
+        container_type, map_func_name = (
             (type(self), "wf.map_imagery")
             if result_type is self._element_type
             else (List[result_type], "wf.map")
         )
-        return container_type._from_apply(func, self, delayed_func)
+        return container_type._from_apply(map_func_name, self, func)
 
     @typecheck_promote(None, reverse=Bool)
     def sorted(self, key, reverse=False):
@@ -549,7 +550,7 @@ class ImageCollection(BandsMixin, CollectionMixin, ImageCollectionBase):
         delayed_func = Function.from_callable(
             func, ImageCollection, Image, ImageCollection
         )
-        return_type = delayed_func._type_params[-1]
+        return_type = delayed_func.return_type
 
         out_type, func = (
             (ImageCollection, "wf.ImageCollection.map_window_ic")
@@ -717,7 +718,7 @@ class ImageCollection(BandsMixin, CollectionMixin, ImageCollectionBase):
 
         Returns
         -------
-        imgs: ImageCollection
+        imgs: `ImageCollection`
 
         Example
         -------
@@ -791,9 +792,17 @@ class ImageCollection(BandsMixin, CollectionMixin, ImageCollectionBase):
             or `~.workflows.types.geospatial.FeatureCollection`),
             in which case pixels *outside* the vector are masked.
         replace: Bool, default False
-            If False (default), adds this mask to the current one,
-            so already-masked pixels remain masked,
-            or replaces the current mask with this new one if True.
+            Whether to add to the ImageCollection's current mask, or replace it.
+
+            If False (default):
+
+            * Adds this mask to the current one, so already-masked pixels remain masked.
+            * Masked-out pixels in the `mask` are ignored (considered False).
+
+            If True:
+
+            * Replaces the current mask with this new one.
+            * Masked-out pixels in the `mask` are also masked in the result.
 
         Example
         -------
@@ -890,8 +899,6 @@ class ImageCollection(BandsMixin, CollectionMixin, ImageCollectionBase):
         also gets the field ``"group"`` added to its `~.Image.properties`, which identifies which group
         it belongs to.
 
-        Type-theoretically: ``groupby(func: Function[Image, {}, T]) -> ImageCollectionGroupby[T]``
-
         If the `ImageCollection` is empty, or ``func`` results in empty groups,
         `ImageCollectionGroupby.groups` will return an empty `Dict`.
 
@@ -926,7 +933,7 @@ class ImageCollection(BandsMixin, CollectionMixin, ImageCollectionBase):
                 return fields[0] if len(fields) == 1 else fields
 
         delayed_func = Function.from_callable(func, Image)
-        key_type = delayed_func._type_params[-1]
+        key_type = delayed_func.return_type
 
         return ImageCollectionGroupby[key_type](self, delayed_func)
 
@@ -1375,6 +1382,77 @@ class ImageCollection(BandsMixin, CollectionMixin, ImageCollectionBase):
         axis = list(axis) if isinstance(axis, tuple) else axis
         return return_type._from_apply("wf.count", self, axis)
 
+    @typecheck_promote(operation=Str)
+    def reduction(self, operation, axis=None):
+        """
+        Reduce the `ImageCollection` along the provided ``axis``, or across all pixels in the image
+        collection if no ``axis`` argument is provided.
+
+        If the `ImageCollection` is empty, an empty (of the type determined by ``axis``) will be returned.
+
+        Parameters
+        ----------
+        operation: {"min", "max", "mean", "median", "mosaic", "sum", "std", "count"}
+            A string indicating the reduction method to apply along the specified axis.
+            If operation is "mosaic", ``axis`` must be "images".
+        axis: {None, "images", "bands", "pixels", ("images", "pixels"), ("bands", "pixels"), ("images", "bands")}
+            A Python string indicating the axis along which to perform the reduction.
+
+            Options:
+
+            * ``"images"``: Returns an `.Image`
+              containing the reduction across all scenes, for each pixel in each
+              band (i.e., a temporal reduction.)
+            * ``"bands"``: Returns a new `ImageCollection` with one band, named according to ``operation``,
+              containing the reduction across all bands, for each pixel in each
+              scene.
+            * ``"pixels"`` Returns a ``List[Dict[Str, Float]]`` containing each band's
+              reduction, for each scene in the collection.
+            * ``None``: Returns a `.Float` that represents the reduction of the
+              entire `ImageCollection`, across all scenes, bands, and pixels.
+            * ``("images", "pixels")``: Returns a ``Dict[Str, Float]`` containing the reduction
+              across all scenes, for each band, keyed by band name.
+            * ``("bands", "pixels")``: Returns a ``List[Float]`` containing the reduction
+              across all bands, for each scene.
+            * ``("images", "bands")``: Returns an `.Image` containing the reduction
+              across all scenes and bands.
+
+        Returns
+        -------
+        ``Dict[Str, Float]``, ``List[Float]``, ``List[Dict[Str, Float]]``, `.ImageCollection`, `.Image` or `.Float`
+            Composite along the provided ``axis``.  See the options for the ``axis``
+            argument for details.
+
+        Example
+        -------
+        >>> import descarteslabs.workflows as wf
+        >>> col = wf.ImageCollection.from_id("landsat:LC08:01:RT:TOAR")
+        >>> std_reduction = col.reduction("std", axis="images")
+        >>> std_col = col.reduction("std", axis="bands")
+        >>> band_stds_per_scene = col.reduction("std", axis="pixels")
+        >>> scene_stds = col.reduction("std", axis=("bands", "pixels"))
+        >>> band_stds = col.reduction("std", axis=("images", "pixels"))
+        >>> std = col.reduction("std", axis=None)
+        """
+        if operation.literal_value is not None and operation.literal_value not in [
+            "min",
+            "max",
+            "mean",
+            "median",
+            "mosaic",
+            "sum",
+            "std",
+            "count",
+        ]:
+            raise ValueError(
+                "Invalid operation {!r}, must be 'min', 'max', 'mean', 'median', 'mosaic', "
+                "'sum', 'std', or 'count'.".format(operation.literal_value)
+            )
+
+        return_type = self._stats_return_type(axis)
+        axis = list(axis) if isinstance(axis, tuple) else axis
+        return return_type._from_apply("wf.reduction", self, operation, axis=axis)
+
     @typecheck_promote(Bool)
     def mosaic(self, reverse=False):
         """
@@ -1407,7 +1485,7 @@ class ImageCollection(BandsMixin, CollectionMixin, ImageCollectionBase):
     @typecheck_promote((Int, Slice))
     def __getitem__(self, item):
         return_type = Image if isinstance(item, Int) else self
-        return return_type._from_apply("wf.getitem", self, item)
+        return return_type._from_apply("wf.get", self, item)
 
     # Binary comparators
     @typecheck_promote((Image, lambda: ImageCollection, Int, Float))
@@ -1810,7 +1888,11 @@ class ImageCollection(BandsMixin, CollectionMixin, ImageCollectionBase):
     @typecheck_promote(
         (lambda: ImageCollection, Int, Float),
         mask=Bool,
-        bandinfo=(NoneType, Dict[Str, Dict[Str, Any]]),
+        bandinfo=lambda self: (
+            NoneType,
+            Dict[Str, Dict[Str, Any]],
+            type(self.bandinfo),
+        ),
     )
     def replace_empty_with(self, fill, mask=True, bandinfo=None):
         """
@@ -2014,3 +2096,203 @@ class ImageCollection(BandsMixin, CollectionMixin, ImageCollectionBase):
     @typecheck_promote((Image, lambda: ImageCollection, Int, Float))
     def __rpow__(self, other):
         return self._from_apply("wf.pow", other, self)
+
+    def tile_layer(
+        self,
+        name=None,
+        scales=None,
+        colormap=None,
+        reduction="mosaic",
+        checkerboard=True,
+        log_level=logging.DEBUG,
+        **parameter_overrides,
+    ):
+        """
+        Reduce this `ImageCollection` into an `Image`, and create a `.WorkflowsLayer` for it.
+
+        Generally, use `ImageCollection.visualize` for displaying on map.
+        Only use this method if you're managing your own ipyleaflet Map instances,
+        and creating more custom visualizations.
+
+        An empty  `ImageCollection` will be rendered as a checkerboard (default) or blank tile.
+
+        Parameters
+        ----------
+        name: str
+            The name of the layer.
+        scales: list of lists, default None
+            The scaling to apply to each band in the `ImageCollection` after being reduced into an `Image`.
+
+            If `ImageCollection` contains 3 bands, ``scales`` must be a list like ``[(0, 1), (0, 1), (-1, 1)]``.
+
+            If `ImageCollection` contains 1 band, ``scales`` must be a list like ``[(0, 1)]``,
+            or just ``(0, 1)`` for convenience
+
+            If None, each 256x256 tile will be scaled independently.
+            based on the min and max values of its data.
+        colormap: str, default None
+            The name of the colormap to apply to the `ImageCollection` after being reduced.
+            Only valid if the `ImageCollection` has a single band.
+        reduction: {"mosaic", "min", "max", "mean", "median", "sum", "std", "count"}
+            The method used to reduce the `ImageCollection` into an `Image`.
+            Reduction is performed before applying a colormap or scaling.
+        checkerboard: bool, default True
+            Whether to display a checkerboarded background for missing or masked data.
+        log_level: int, default logging.DEBUG
+            Only listen for log records at or above this log level during tile computation.
+            See https://docs.python.org/3/library/logging.html#logging-levels for valid
+            log levels.
+        **parameter_overrides: JSON-serializable value, Proxytype, or ipywidgets.Widget
+            Values---or ipywidgets---for any parameters that this `ImageCollection` depends on.
+
+            If this `ImageCollection` depends on ``wf.widgets``, you don't have to pass anything for those---any
+            widgets it depends on are automatically linked to the layer. However, you can override
+            their current values (or widgets) by passing new values (or ipywidget instances) here.
+
+            Values can be given as Proxytypes, or as Python objects like numbers,
+            lists, and dicts that can be promoted to them.
+            These arguments cannot depend on any parameters.
+
+            If an ``ipywidgets.Widget`` is given, it's automatically linked, so updating the widget causes
+            the argument value to change, and the layer to update.
+
+            Once these initial argument values are set, they can be modified by assigning to
+            `~.WorkflowsLayer.parameters` on the returned `WorkflowsLayer`.
+
+            For more information, see the docstring to `ParameterSet`.
+
+        Returns
+        -------
+        layer: `.WorkflowsLayer`
+        """
+        from ... import interactive
+
+        return interactive.WorkflowsLayer(
+            self,
+            name=name,
+            scales=scales,
+            colormap=colormap,
+            reduction=reduction,
+            checkerboard=checkerboard,
+            log_level=log_level,
+            parameter_overrides=parameter_overrides,
+        )
+
+    def visualize(
+        self,
+        name,
+        scales=None,
+        colormap=None,
+        reduction="mosaic",
+        checkerboard=True,
+        log_level=logging.DEBUG,
+        map=None,
+        **parameter_overrides,
+    ):
+        """
+        Reduce this `ImageCollection` into an `Image`, and add to `wf.map <.interactive.map>`,
+        or replace a layer with the same name.
+
+        An empty  `ImageCollection` will be rendered as a checkerboard (default) or blank tile.
+
+        Parameters
+        ----------
+        name: str
+            The name of the layer.
+
+            If a layer with this name already exists on `wf.map <.interactive.map>`,
+            it will be replaced with this reduced `ImageCollection`, scales, and colormap.
+            This allows you to re-run cells in Jupyter calling `visualize`
+            without adding duplicate layers to the map.
+        scales: list of lists, default None
+            The scaling to apply to each band in the `ImageCollection` after being reduced into an `Image`.
+
+            If `ImageCollection` contains 3 bands, ``scales`` must be a list like ``[(0, 1), (0, 1), (-1, 1)]``.
+
+            If `ImageCollection` contains 1 band, ``scales`` must be a list like ``[(0, 1)]``,
+            or just ``(0, 1)`` for convenience
+
+            If None, each 256x256 tile will be scaled independently.
+            based on the min and max values of its data.
+        colormap: str, default None
+            The name of the colormap to apply to the `ImageCollection` after being reduced.
+            Only valid if the `ImageCollection` has a single band.
+        reduction: {"mosaic", "min", "max", "mean", "median", "sum", "std", "count"}
+            The method used to reduce the `ImageCollection` into an `Image`.
+            Compositing is performed before applying a colormap or scaling.
+        checkerboard: bool, default True
+            Whether to display a checkerboarded background for missing or masked data.
+        log_level: int, default logging.DEBUG
+            Only listen for log records at or above this log level during tile computation.
+            See https://docs.python.org/3/library/logging.html#logging-levels for valid
+            log levels.
+        map: `.Map` or `.MapApp`, optional, default None
+            The `.Map` (or plain ipyleaflet Map) instance on which to show the reduced `ImageCollection`.
+            If None (default), uses `wf.map <.interactive.map>`, the singleton Workflows `.MapApp` object.
+        **parameter_overrides: JSON-serializable value, Proxytype, or ipywidgets.Widget
+            Values---or ipywidgets---for any parameters that this `ImageCollection` depends on.
+
+            If this `ImageCollection` depends on ``wf.widgets``, you don't have to pass anything for those---any
+            widgets it depends on are automatically linked to the layer. However, you can override
+            their current values (or widgets) by passing new values (or ipywidget instances) here.
+
+            Values can be given as Proxytypes, or as Python objects like numbers,
+            lists, and dicts that can be promoted to them.
+            These arguments cannot depend on any parameters.
+
+            If an ``ipywidgets.Widget`` is given, it's automatically linked, so updating the widget causes
+            the argument value to change, and the map to update. Running `visualize` again and passing in
+            a different widget instance will un-link the old one automatically.
+
+            Once these initial argument values are set, they can be modified by assigning to
+            `~.WorkflowsLayer.parameters` on the returned `WorkflowsLayer`.
+
+            For more information, see the docstring to `ParameterSet`.
+
+        Returns
+        -------
+        layer: WorkflowsLayer
+            The layer displaying this reduced `ImageCollection`. Either a new `WorkflowsLayer` if one was created,
+            or the layer with the same ``name`` that was already on the map.
+
+        Example
+        -------
+        >>> import descarteslabs.workflows as wf
+        >>> col = wf.ImageCollection.from_id("landsat:LC08:01:RT:TOAR")
+        >>> rgb = col.pick_bands("red green blue")
+        >>> lyr = min_rgb.visualize(
+        ...     name="My Cool Min RGB",
+        ...     scales=[0, 1],
+        ...     colormap="viridis",
+        ...     reduction="min",
+        ... )  # doctest: +SKIP
+        >>> wf.map  # doctest: +SKIP
+        >>> # `wf.map` actually displays the map; right click and open in new view in JupyterLab
+        """
+        from ... import interactive
+
+        if map is None:
+            map = interactive.map
+
+        for layer in map.layers:
+            if layer.name == name:
+                with layer.hold_url_updates():
+                    layer.set_imagery(self, **parameter_overrides)
+                    layer.set_scales(scales, new_colormap=colormap)
+                    layer.reduction = reduction
+                    layer.checkerboard = checkerboard
+                    if log_level is not None:
+                        layer.log_level = log_level
+                return layer
+        else:
+            layer = self.tile_layer(
+                name=name,
+                scales=scales,
+                colormap=colormap,
+                reduction=reduction,
+                checkerboard=checkerboard,
+                log_level=log_level,
+                **parameter_overrides,
+            )
+            map.add_layer(layer)
+            return layer
